# Change History

## 2022.11.28

* Bumped dependencies
* Bumped python version range to (3.9, 3.10, 3.11)

## 2022.7.24

* Bumped dependencies for development and test
* Moved from sphinx to mkdocs
* Moved documentation to https://codes.dilettant.life/docs/gelee
* Moved tracker to https://todo.sr.ht/~sthagen/gelee
* Moved normative source repo to https://git.sr.ht/~sthagen/gelee

## 2021

### 2021.10.24

* Changed the commandline API now using commands
* Commandline API now based on [Typer](https://pypi.org/project/typer/)
* Changed development tools
* For now no updates to the docker image ...
* Added a wheel to the package

### 2021.4.29 (0.0.6)

* Removed duplicates from arguments
* Backported to Python 3.7 and optimizing log payloads
* Sixth release on PyPI

### 2021.4.28.1 (0.0.5)

* Hot fix for optimized empty csv and xml file handling
* Fifth release on PyPI

### 2021.4.28 (0.0.4)

* Fixed gelee app (console script)
* Fixed single file path use case
* Enhanced detection of and report on empty CSV as well as XML files (invalid use cases)
* Enhanced report on non-existing paths
* Added more tests to detect regressions
* Fixed summary singular / plural for total paths
* Fourth release on PyPI

### 2021.4.27 (0.0.3)

* Added YAML well-formed lint
* Hardened processing of files without extension
* Added documentation
* Third release on PyPI

### 2021.4.26 (0.0.2)

* Added CSV well-formed lint
* Added INI well-formed lint
* Added JSON/GeoJSON well-formed lint
* Added TOML well-formed lint
* Added XML well-formed lint
* Fixed debug logic
* Second release on PyPI

### 2021.4.25 (0.0.1)

* Initial release on PyPI

